@@ -53,132 +53,142 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
     objects in the original space in the embedding space.
     """
 
-    repo_name = "object2vec"
-    repo_version = 1
-    MINI_BATCH_SIZE = 32
+    repo_name: str = "object2vec"
+    repo_version: str = "1"
+    MINI_BATCH_SIZE: int = 32
 
-    enc_dim = hp("enc_dim", (ge(4), le(10000)), "An integer in [4, 10000]", int)
-    mini_batch_size = hp("mini_batch_size", (ge(1), le(10000)), "An integer in [1, 10000]", int)
-    epochs = hp("epochs", (ge(1), le(100)), "An integer in [1, 100]", int)
-    early_stopping_patience = hp(
+    enc_dim: hp = hp("enc_dim", (ge(4), le(10000)), "An integer in [4, 10000]", int)
+    mini_batch_size: hp = hp("mini_batch_size", (ge(1), le(10000)), "An integer in [1, 10000]", int)
+    epochs: hp = hp("epochs", (ge(1), le(100)), "An integer in [1, 100]", int)
+    early_stopping_patience: hp = hp(
         "early_stopping_patience", (ge(1), le(5)), "An integer in [1, 5]", int
     )
-    early_stopping_tolerance = hp(
+    early_stopping_tolerance: hp = hp(
         "early_stopping_tolerance", (ge(1e-06), le(0.1)), "A float in [1e-06, 0.1]", float
     )
-    dropout = hp("dropout", (ge(0.0), le(1.0)), "A float in [0.0, 1.0]", float)
-    weight_decay = hp("weight_decay", (ge(0.0), le(10000.0)), "A float in [0.0, 10000.0]", float)
-    bucket_width = hp("bucket_width", (ge(0), le(100)), "An integer in [0, 100]", int)
-    num_classes = hp("num_classes", (ge(2), le(30)), "An integer in [2, 30]", int)
-    mlp_layers = hp("mlp_layers", (ge(1), le(10)), "An integer in [1, 10]", int)
-    mlp_dim = hp("mlp_dim", (ge(2), le(10000)), "An integer in [2, 10000]", int)
-    mlp_activation = hp(
+    dropout: hp = hp("dropout", (ge(0.0), le(1.0)), "A float in [0.0, 1.0]", float)
+    weight_decay: hp = hp(
+        "weight_decay", (ge(0.0), le(10000.0)), "A float in [0.0, 10000.0]", float
+    )
+    bucket_width: hp = hp("bucket_width", (ge(0), le(100)), "An integer in [0, 100]", int)
+    num_classes: hp = hp("num_classes", (ge(2), le(30)), "An integer in [2, 30]", int)
+    mlp_layers: hp = hp("mlp_layers", (ge(1), le(10)), "An integer in [1, 10]", int)
+    mlp_dim: hp = hp("mlp_dim", (ge(2), le(10000)), "An integer in [2, 10000]", int)
+    mlp_activation: hp = hp(
         "mlp_activation", isin("tanh", "relu", "linear"), 'One of "tanh", "relu", "linear"', str
     )
-    output_layer = hp(
+    output_layer: hp = hp(
         "output_layer",
         isin("softmax", "mean_squared_error"),
         'One of "softmax", "mean_squared_error"',
         str,
     )
-    optimizer = hp(
+    optimizer: hp = hp(
         "optimizer",
         isin("adagrad", "adam", "rmsprop", "sgd", "adadelta"),
         'One of "adagrad", "adam", "rmsprop", "sgd", "adadelta"',
         str,
     )
-    learning_rate = hp("learning_rate", (ge(1e-06), le(1.0)), "A float in [1e-06, 1.0]", float)
+    learning_rate: hp = hp("learning_rate", (ge(1e-06), le(1.0)), "A float in [1e-06, 1.0]", float)
 
-    negative_sampling_rate = hp(
+    negative_sampling_rate: hp = hp(
         "negative_sampling_rate", (ge(0), le(100)), "An integer in [0, 100]", int
     )
-    comparator_list = hp(
+    comparator_list: hp = hp(
         "comparator_list",
         _list_check_subset(["hadamard", "concat", "abs_diff"]),
         'Comma-separated of hadamard, concat, abs_diff. E.g. "hadamard,abs_diff"',
         str,
     )
-    tied_token_embedding_weight = hp(
+    tied_token_embedding_weight: hp = hp(
         "tied_token_embedding_weight", (), "Either True or False", bool
     )
-    token_embedding_storage_type = hp(
+    token_embedding_storage_type: hp = hp(
         "token_embedding_storage_type",
         isin("dense", "row_sparse"),
         'One of "dense", "row_sparse"',
         str,
     )
 
-    enc0_network = hp(
+    enc0_network: hp = hp(
         "enc0_network",
         isin("hcnn", "bilstm", "pooled_embedding"),
         'One of "hcnn", "bilstm", "pooled_embedding"',
         str,
     )
-    enc1_network = hp(
+    enc1_network: hp = hp(
         "enc1_network",
         isin("hcnn", "bilstm", "pooled_embedding", "enc0"),
         'One of "hcnn", "bilstm", "pooled_embedding", "enc0"',
         str,
     )
-    enc0_cnn_filter_width = hp("enc0_cnn_filter_width", (ge(1), le(9)), "An integer in [1, 9]", int)
-    enc1_cnn_filter_width = hp("enc1_cnn_filter_width", (ge(1), le(9)), "An integer in [1, 9]", int)
-    enc0_max_seq_len = hp("enc0_max_seq_len", (ge(1), le(5000)), "An integer in [1, 5000]", int)
-    enc1_max_seq_len = hp("enc1_max_seq_len", (ge(1), le(5000)), "An integer in [1, 5000]", int)
-    enc0_token_embedding_dim = hp(
+    enc0_cnn_filter_width: hp = hp(
+        "enc0_cnn_filter_width", (ge(1), le(9)), "An integer in [1, 9]", int
+    )
+    enc1_cnn_filter_width: hp = hp(
+        "enc1_cnn_filter_width", (ge(1), le(9)), "An integer in [1, 9]", int
+    )
+    enc0_max_seq_len: hp = hp("enc0_max_seq_len", (ge(1), le(5000)), "An integer in [1, 5000]", int)
+    enc1_max_seq_len: hp = hp("enc1_max_seq_len", (ge(1), le(5000)), "An integer in [1, 5000]", int)
+    enc0_token_embedding_dim: hp = hp(
         "enc0_token_embedding_dim", (ge(2), le(1000)), "An integer in [2, 1000]", int
     )
-    enc1_token_embedding_dim = hp(
+    enc1_token_embedding_dim: hp = hp(
         "enc1_token_embedding_dim", (ge(2), le(1000)), "An integer in [2, 1000]", int
     )
-    enc0_vocab_size = hp("enc0_vocab_size", (ge(2), le(3000000)), "An integer in [2, 3000000]", int)
-    enc1_vocab_size = hp("enc1_vocab_size", (ge(2), le(3000000)), "An integer in [2, 3000000]", int)
-    enc0_layers = hp("enc0_layers", (ge(1), le(4)), "An integer in [1, 4]", int)
-    enc1_layers = hp("enc1_layers", (ge(1), le(4)), "An integer in [1, 4]", int)
-    enc0_freeze_pretrained_embedding = hp(
+    enc0_vocab_size: hp = hp(
+        "enc0_vocab_size", (ge(2), le(3000000)), "An integer in [2, 3000000]", int
+    )
+    enc1_vocab_size: hp = hp(
+        "enc1_vocab_size", (ge(2), le(3000000)), "An integer in [2, 3000000]", int
+    )
+    enc0_layers: hp = hp("enc0_layers", (ge(1), le(4)), "An integer in [1, 4]", int)
+    enc1_layers: hp = hp("enc1_layers", (ge(1), le(4)), "An integer in [1, 4]", int)
+    enc0_freeze_pretrained_embedding: hp = hp(
         "enc0_freeze_pretrained_embedding", (), "Either True or False", bool
     )
-    enc1_freeze_pretrained_embedding = hp(
+    enc1_freeze_pretrained_embedding: hp = hp(
         "enc1_freeze_pretrained_embedding", (), "Either True or False", bool
     )
 
     def __init__(
         self,
-        role,
-        instance_count=None,
-        instance_type=None,
-        epochs=None,
-        enc0_max_seq_len=None,
-        enc0_vocab_size=None,
-        enc_dim=None,
-        mini_batch_size=None,
-        early_stopping_patience=None,
-        early_stopping_tolerance=None,
-        dropout=None,
-        weight_decay=None,
-        bucket_width=None,
-        num_classes=None,
-        mlp_layers=None,
-        mlp_dim=None,
-        mlp_activation=None,
-        output_layer=None,
-        optimizer=None,
-        learning_rate=None,
-        negative_sampling_rate=None,
-        comparator_list=None,
-        tied_token_embedding_weight=None,
-        token_embedding_storage_type=None,
-        enc0_network=None,
-        enc1_network=None,
-        enc0_cnn_filter_width=None,
-        enc1_cnn_filter_width=None,
-        enc1_max_seq_len=None,
-        enc0_token_embedding_dim=None,
-        enc1_token_embedding_dim=None,
-        enc1_vocab_size=None,
-        enc0_layers=None,
-        enc1_layers=None,
-        enc0_freeze_pretrained_embedding=None,
-        enc1_freeze_pretrained_embedding=None,
+        role: str,
+        instance_count: Optional[Union[int, PipelineVariable]] = None,
+        instance_type: Optional[Union[str, PipelineVariable]] = None,
+        epochs: Optional[int] = None,
+        enc0_max_seq_len: Optional[int] = None,
+        enc0_vocab_size: Optional[int] = None,
+        enc_dim: Optional[int] = None,
+        mini_batch_size: Optional[int] = None,
+        early_stopping_patience: Optional[int] = None,
+        early_stopping_tolerance: Optional[float] = None,
+        dropout: Optional[float] = None,
+        weight_decay: Optional[float] = None,
+        bucket_width: Optional[int] = None,
+        num_classes: Optional[int] = None,
+        mlp_layers: Optional[int] = None,
+        mlp_dim: Optional[int] = None,
+        mlp_activation: Optional[str] = None,
+        output_layer: Optional[str] = None,
+        optimizer: Optional[str] = None,
+        learning_rate: Optional[float] = None,
+        negative_sampling_rate: Optional[int] = None,
+        comparator_list: Optional[str] = None,
+        tied_token_embedding_weight: Optional[bool] = None,
+        token_embedding_storage_type: Optional[str] = None,
+        enc0_network: Optional[str] = None,
+        enc1_network: Optional[str] = None,
+        enc0_cnn_filter_width: Optional[int] = None,
+        enc1_cnn_filter_width: Optional[int] = None,
+        enc1_max_seq_len: Optional[int] = None,
+        enc0_token_embedding_dim: Optional[int] = None,
+        enc1_token_embedding_dim: Optional[int] = None,
+        enc1_vocab_size: Optional[int] = None,
+        enc0_layers: Optional[int] = None,
+        enc1_layers: Optional[int] = None,
+        enc0_freeze_pretrained_embedding: Optional[bool] = None,
+        enc1_freeze_pretrained_embedding: Optional[bool] = None,
         **kwargs
     ):
         """Object2Vec is :class:`Estimator` used for anomaly detection.
@@ -212,9 +222,9 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
                 endpoints use this role to access training data and model
                 artifacts. After the endpoint is created, the inference code
                 might use the IAM role, if accessing AWS resource.
-            instance_count (int): Number of Amazon EC2 instances to use
+            instance_count (int or PipelineVariable): Number of Amazon EC2 instances to use
                 for training.
-            instance_type (str): Type of EC2 instance to use for training,
+            instance_type (str or PipelineVariable): Type of EC2 instance to use for training,
                 for example, 'ml.c4.xlarge'.
             epochs (int): Total number of epochs for SGD training
             enc0_max_seq_len (int): Maximum sequence length
@@ -358,7 +368,7 @@ class Object2VecModel(Model):
         """Initialization for Object2VecModel class.
 
         Args:
-            model_data (str): The S3 location of a SageMaker model data
+            model_data (str or PipelineVariable): The S3 location of a SageMaker model data
                 ``.tar.gz`` file.
             role (str): An AWS IAM role (either name or full ARN). The Amazon
                 SageMaker training jobs and APIs that create Amazon SageMaker
